@@ -437,7 +437,7 @@ def normalize_json_keys(json_obj: dict) -> dict:
     """
     new_json_obj = {}
 
-    for key in json_obj:
+    for key in json_obj.keys():
         new_json_obj[normalize_json_key(key)] = json_obj[key]
 
     return new_json_obj
@@ -636,7 +636,7 @@ def member_report(member_id):
                 overall_samples.append(annotation)
 
             except Exception as e:
-                print(e)
+                # print(e)
                 # print(f"This DOI was excluded: {sample['DOI']}")
 
     key = f"{REPORT_PATH}/members/{member_id}/preservation-report.json"
