@@ -334,7 +334,7 @@ def download_remote(
 
 
 def preservation_status(
-    model, container_title, issn, volume, no=None
+    model, container_title, issn, volume, no=None, year=None
 ) -> (dict | None, str):
     """
     Determine whether a DOI is preserved in model
@@ -362,6 +362,15 @@ def preservation_status(
         elif volume in vols_in_prog:
             return preserved_item, False
 
+        if year:
+            years = [x.strip() for x in pi.preserved_years.split(";")]
+            years_in_prog = [x.strip() for x in pi.in_progress_years.split(";")]
+
+            if str(year) in years:
+                return preserved_item, True
+            elif str(year) in years_in_prog:
+                return preserved_item, False
+
     return None, False
 
 
